import { WorkspaceConfiguration } from './types/config.js';
import type { Issue } from './types/issues.js';
import type { WorkspaceManifests } from './types/workspace.js';
import type { PeerDependencies, InstalledBinaries } from './types/workspace.js';
import type { PackageJson } from 'type-fest';
type Options = {
    isStrict: boolean;
    ignoreDependencies: string[];
};
export default class DependencyDeputy {
    isStrict: boolean;
    _manifests: WorkspaceManifests;
    manifests: Map<string, PackageJson>;
    ignoreDependencies: string[];
    referencedDependencies: Map<string, Set<string>>;
    peerDependencies: Map<string, PeerDependencies>;
    installedBinaries: Map<string, InstalledBinaries>;
    tsConfigPathGlobs: Map<string, string[]>;
    constructor({ isStrict, ignoreDependencies }: Options);
    addWorkspace({ name, dir, manifestPath, manifest, }: {
        name: string;
        dir: string;
        manifestPath: string;
        manifest: PackageJson;
    }): void;
    getManifest(workspaceName: string): PackageJson | undefined;
    getWorkspaceManifest(workspaceName: string): {
        workspaceDir: string;
        manifestPath: string;
        scripts: string[];
        dependencies: string[];
        peerDependencies: string[];
        optionalDependencies: string[];
        devDependencies: string[];
        allDependencies: string[];
    } | undefined;
    getProductionDependencies(workspaceName: string): string[];
    getDevDependencies(workspaceName: string): string[];
    setInstalledBinaries(workspaceName: string, installedBinaries: Map<string, Set<string>>): void;
    getInstalledBinaries(workspaceName: string): InstalledBinaries | undefined;
    addTypeScriptConfigPathGlobs(workspaceName: string, paths: Record<string, string[]>): void;
    addReferencedDependency(workspaceName: string, packageName: string): void;
    addPeerDependencies(workspaceName: string, peerDependencies: Map<string, Set<string>>): void;
    getPeerDependencies(workspaceName: string, dependency: string): string[];
    maybeAddListedReferencedDependency(workspace: {
        name: string;
        dir: string;
        config: WorkspaceConfiguration;
        ancestors: string[];
    }, moduleSpecifier: string): string | undefined;
    isInternalDependency(workspaceName: string, moduleSpecifier: string): boolean | undefined;
    private isAliasedDependency;
    private isInDependencies;
    settleDependencyIssues(): {
        dependencyIssues: Issue[];
        devDependencyIssues: Issue[];
    };
}
export {};
