import { readFileSync } from 'fs';
import { getBinariesFromScripts } from '../../util/binaries/index.js';
import { timerify } from '../../util/performance.js';
import { hasDependency } from '../../util/plugin.js';
export const NAME = 'husky';
export const ENABLERS = ['husky'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = [
    '.husky/commit-msg',
    '.husky/pre-{applypatch,commit,merge-commit,push,rebase,receive}',
    '.husky/post-{checkout,commit,merge,rewrite}',
];
const findHuskyDependencies = async (configFilePath, { manifest, rootConfig }) => {
    const script = readFileSync(configFilePath);
    const scripts = String(script)
        .split('\n')
        .map(script => script.trim());
    const binaries = getBinariesFromScripts(scripts, {
        manifest,
        ignore: rootConfig.ignoreBinaries,
        knownGlobalsOnly: true,
    });
    return binaries;
};
export const findDependencies = timerify(findHuskyDependencies);
