import { compact } from '../../util/array.js';
import { getBinariesFromScripts } from '../../util/binaries/index.js';
import { _load } from '../../util/loader.js';
import { timerify } from '../../util/performance.js';
import { hasDependency } from '../../util/plugin.js';
export const NAME = 'Nx';
export const ENABLERS = [/^@nrwl\//];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['{apps,libs}/**/project.json'];
const findNxDependencies = async (configFilePath, { manifest }) => {
    const config = await _load(configFilePath);
    if (!config)
        return [];
    const targets = config.targets ? Object.values(config.targets) : [];
    const executors = compact(targets
        .map(target => target?.executor)
        .filter(executor => executor && !executor.startsWith('.'))
        .map(executor => executor?.split(':')[0]));
    const scripts = compact(targets
        .filter(target => target.executor === 'nx:run-commands')
        .flatMap(target => (target.options?.commands ?? target.options?.command ? [target.options.command] : [])));
    const binaries = getBinariesFromScripts(scripts, { manifest, knownGlobalsOnly: true });
    return [...executors, ...binaries];
};
export const findDependencies = timerify(findNxDependencies);
