import { compact } from '../../util/array.js';
import { _load } from '../../util/loader.js';
import { timerify } from '../../util/performance.js';
import { hasDependency } from '../../util/plugin.js';
import { getEnvPackageName, getExternalReporters } from './helpers.js';
export const NAME = 'Vitest';
export const ENABLERS = ['vitest'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['vitest.config.ts', 'vite.config.ts'];
export const ENTRY_FILE_PATTERNS = ['**/*.{test,spec}.{js,mjs,cjs,ts,mts,cts,jsx,tsx}'];
const findVitestDependencies = async (configFilePath) => {
    const config = await _load(configFilePath);
    if (!config || !config.test)
        return [];
    const cfg = config.test;
    const environments = cfg.environment ? [getEnvPackageName(cfg.environment)] : [];
    const reporters = getExternalReporters(cfg.reporters);
    const coverage = cfg.coverage?.provider ? [`@vitest/coverage-${cfg.coverage.provider}`] : [];
    return compact([...environments, ...reporters, ...coverage]);
};
export const findDependencies = timerify(findVitestDependencies);
