import { IGNORED_GLOBAL_BINARIES } from '../../constants.js';
import { getArgumentValues } from '../plugin.js';
import { toCamelCase } from '../plugin.js';
import * as BinaryResolvers from './binaries/index.js';
import * as GlobalBinaryResolvers from './globals/index.js';
const normalizeBinaries = (command) => command
    .replace(/(\.\/)?node_modules\/\.bin\/(\w+)/, '$2')
    .replace(/\$\(npm bin\)\/(\w+)/, '$1')
    .replace(/(\S+)@.*/, '$1');
const stripEnvironmentVariables = (value) => value.replace(/([A-Z][^ ]*)=([^ ])+ /g, '');
const getLoaderArgumentValues = (value) => getArgumentValues(value, / (--(experimental-)?loader|--require|-r)[ =]([^ ]+)/g);
export const getDependenciesFromLoaderArguments = (args) => getLoaderArgumentValues(' ' + args.join(' '))
    .filter(scripts => !scripts.startsWith('.'))
    .map(script => {
    if (script.startsWith('@')) {
        const [scope, packageName] = script.split('/');
        return [scope, packageName].join('/');
    }
    return script.split('/')[0];
});
export const getBinariesFromScripts = (npmScripts, { manifest, ignore = [], knownGlobalsOnly = false, }) => Array.from(npmScripts.reduce((binaries, script) => {
    script
        .split(' && ')
        .flatMap(command => command.split(' -- '))
        .map(normalizeBinaries)
        .filter(command => /^\w/.test(command))
        .map(stripEnvironmentVariables)
        .flatMap(command => {
        const [binary, ...args] = command.trim().split(' ');
        const camelCased = toCamelCase(binary);
        if (['bun', 'deno'].includes(binary))
            return [];
        if (camelCased in GlobalBinaryResolvers) {
            return GlobalBinaryResolvers[camelCased].resolve(binary, args, manifest);
        }
        if (knownGlobalsOnly)
            return [];
        if (camelCased in BinaryResolvers) {
            return BinaryResolvers[camelCased].resolve(binary, args);
        }
        const dependenciesFromArguments = getDependenciesFromLoaderArguments(args);
        return [binary, ...dependenciesFromArguments];
    })
        .forEach(binary => binary && binaries.add(binary));
    return binaries;
}, new Set())).filter(binaryName => !IGNORED_GLOBAL_BINARIES.includes(binaryName) && !ignore.includes(binaryName));
