import { ts } from 'ts-morph';
import { _findReferences, hasExternalReferences, hasInternalReferences } from './project.js';
export const findUnusedClassMembers = (declaration, filePath) => {
    const members = declaration.getMembers();
    return members
        .filter((member) => {
        const isPrivate = Boolean(member.getCombinedModifierFlags() & ts.ModifierFlags.Private);
        if (!isPrivate &&
            (member.isKind(ts.SyntaxKind.PropertyDeclaration) || member.isKind(ts.SyntaxKind.MethodDeclaration))) {
            const refs = _findReferences(member);
            return !hasExternalReferences(refs, filePath) && !hasInternalReferences(refs);
        }
        return false;
    })
        .map(member => member.getName());
};
export const findUnusedEnumMembers = (declaration, filePath) => {
    const members = declaration.getMembers();
    return members
        .filter(member => {
        const refs = _findReferences(member);
        return !hasExternalReferences(refs, filePath) && !hasInternalReferences(refs);
    })
        .map(member => member.getName().replace(/['"`]/g, ''));
};
