import { Project } from 'ts-morph';
import { findDuplicateExportedNames, hasReferencingDefaultImport, findReferencingNamespaceNodes, } from 'ts-morph-helpers';
import { timerify } from './performance.js';
const getExportedDeclarations = (sourceFile) => sourceFile.getExportedDeclarations();
const findReferences = (identifier) => identifier?.findReferences() ?? [];
const createProject = (projectOptions, paths) => {
    const project = new Project(projectOptions);
    if (paths)
        paths.forEach(filePath => project.addSourceFileAtPathIfExists(filePath));
    return project;
};
const resolveSourceFileDependencies = (project) => project.resolveSourceFileDependencies();
const removeExternalSourceFiles = (project) => project.getSourceFiles().filter(sourceFile => {
    const filePath = sourceFile.getFilePath();
    if (/\/node_modules\//.test(filePath)) {
        return !project.removeSourceFile(sourceFile);
    }
    return true;
});
export const partitionSourceFiles = (project, productionFiles) => {
    const productionFilePaths = productionFiles.map(sourceFile => sourceFile.getFilePath());
    const usedFiles = new Set();
    const unusedFiles = new Set();
    project.forEach(projectFile => {
        if (productionFilePaths.includes(projectFile.getFilePath())) {
            usedFiles.add(projectFile);
        }
        else {
            unusedFiles.add(projectFile);
        }
    });
    return [usedFiles, unusedFiles];
};
export const hasExternalReferences = (refs, filePath) => {
    const refFiles = new Set(refs.map(r => r.compilerObject.references.map(r => r.fileName)).flat());
    return !(refFiles.size === 1 && [...refFiles][0] === filePath);
};
export const hasInternalReferences = (refs) => {
    return refs.map(ref => ref.getReferences()).flat().length > 1;
};
export const _createProject = timerify(createProject);
export const _resolveSourceFileDependencies = timerify(resolveSourceFileDependencies);
export const _removeExternalSourceFiles = timerify(removeExternalSourceFiles);
export const _findReferencingNamespaceNodes = timerify(findReferencingNamespaceNodes);
export const _hasReferencingDefaultImport = timerify(hasReferencingDefaultImport);
export const _findDuplicateExportedNames = timerify(findDuplicateExportedNames);
export const _getExportedDeclarations = timerify(getExportedDeclarations);
export const _findReferences = timerify(findReferences);
