import { InstalledBinaries, PeerDependencies } from './types/workspace.js';
import type { Configuration, PluginConfiguration, PluginName, WorkspaceConfiguration } from './types/config.js';
import type { Issue } from './types/issues.js';
import type { PackageJson } from 'type-fest';
type WorkspaceManagerOptions = {
    name: string;
    dir: string;
    config: WorkspaceConfiguration;
    manifest: PackageJson;
    ancestorManifests: (PackageJson | undefined)[];
    rootWorkspaceConfig: WorkspaceConfiguration;
    rootConfig: Configuration;
    negatedWorkspacePatterns: string[];
    rootWorkspaceDir: string;
    isProduction: boolean;
};
type ReferencedDependencyIssues = Set<Issue>;
type ReferencedDependencies = Set<string>;
export default class WorkspaceWorker {
    name: string;
    dir: string;
    config: WorkspaceConfiguration;
    ancestorManifests: (PackageJson | undefined)[];
    rootWorkspaceConfig: WorkspaceConfiguration;
    rootConfig: Configuration;
    referencedDependencyIssues: ReferencedDependencyIssues;
    manifest: PackageJson;
    rootWorkspaceDir: string;
    referencedDependencies: ReferencedDependencies;
    peerDependencies: PeerDependencies;
    installedBinaries: InstalledBinaries;
    negatedWorkspacePatterns: string[];
    enabled: Record<PluginName, boolean>;
    isRoot: boolean;
    isProduction: boolean;
    constructor({ name, dir, config, ancestorManifests, rootWorkspaceConfig, rootConfig, negatedWorkspacePatterns, manifest, rootWorkspaceDir, isProduction, }: WorkspaceManagerOptions);
    getConfigForPlugin(pluginName: PluginName): PluginConfiguration;
    init(): Promise<void>;
    setEnabledPlugins(): Promise<void>;
    initReferencedDependencies(): Promise<void>;
    getEntryFilePatterns(): string[];
    getProjectFilePatterns(): string[];
    getPluginEntryFilePatterns(isIncludeProductionEntryFiles?: boolean): string[];
    getPluginProjectFilePatterns(): string[];
    getPluginConfigPatterns(): string[];
    getProductionEntryFilePatterns(): string[];
    getProductionProjectFilePatterns(): string[];
    getProductionPluginEntryFilePatterns(): string[];
    getConfigurationEntryFilePattern(pluginName: PluginName): string[];
    getWorkspaceIgnorePatterns(): string[];
    findDependenciesByPlugins(): Promise<{
        referencedDependencyIssues: ReferencedDependencyIssues;
        referencedDependencies: ReferencedDependencies;
    }>;
    private findDependenciesByPlugin;
}
export {};
